==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_roa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=roa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_message_commentaire' => 'Un message, un commentaire ?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Vous n’avez plus accès à ces forums.',
	'forum_attention_dix_caracteres' => '<b>Attention !</b> votre message doit contenir au moins dix caractères.',
	'forum_attention_trois_caracteres' => '<b>Attention !</b> votre titre doit contenir au moins trois caractères.',
	'forum_attention_trop_caracteres' => '<b>Attention !</b> votre message est trop long (@compte@ caractères) : pour pouvoir être enregistré, il ne doit pas dépasser @max@ caractères.', # MODIF
	'forum_avez_selectionne' => 'Vous avez sélectionné :',
	'forum_cliquer_retour' => 'Cliquez <a href=\'@retour_forum@\'>ici</a> pour continuer.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Ce forum est modéré à priori : votre contribution n’apparaîtra qu’après avoir été validée par un administrateur du site.', # MODIF
	'forum_lien_hyper' => '<b>Lien hypertexte</b> (optionnel)', # MODIF
	'forum_message_definitif' => 'Message définitif : envoyer au site',
	'forum_message_trop_long' => 'Votre message est trop long. La taille maximale est de 20000 caractères.', # MODIF
	'forum_ne_repondez_pas' => 'Ne repondez pas a ce mail mais sur le forum a l’adresse suivante :', # MODIF
	'forum_page_url' => '(Si votre message se réfère à un article publié sur le Web, ou à une page fournissant plus d’informations, vous pouvez indiquer ci-après le titre de la page et son adresse.)',
	'forum_poste_par' => 'Message posté@parauteur@ à la suite de l’article « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Qui êtes-vous ?</b> (optionnel)', # MODIF
	'forum_texte' => 'Texte de votre message :', # MODIF
	'forum_titre' => 'Titre :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Valider ce choix',
	'forum_voir_avant' => 'Voir ce message avant de le poster', # MODIF
	'forum_votre_email' => 'Votre adresse email :', # MODIF
	'forum_votre_nom' => 'Votre nom (ou pseudonyme) :', # MODIF
	'forum_vous_enregistrer' => 'Pour participer à
		ce forum, vous devez vous enregistrer au préalable. Merci
		d’indiquer ci-dessous l’identifiant personnel qui vous a
		été fourni. Si vous n’êtes pas enregistré, vous devez',
	'forum_vous_inscrire' => 'vous inscrire.',

	// I
	'icone_suivi_forums' => 'Suivre/gérer les forums',
	'icone_supprimer_message' => 'Supprimer ce message',
	'icone_valider_message' => 'Valider ce message',
	'info_activer_forum_public' => '<i>Pour activer les forums publics, veuillez choisir leur mode
	de modération par défaut:</i>', # MODIF
	'info_option_email' => 'Lorsqu’un visiteur du site poste un nouveau message dans le forum
		associé à un article, les auteurs de l’article peuvent être
		prévenus de ce message par e-mail. Souhaitez-vous utiliser cette option ?', # MODIF

	// L
	'lien_reponse_site_reference' => 'Réponse au site référencé :', # MODIF

	// O
	'onglet_messages_internes' => 'Messages internes',
	'onglet_messages_publics' => 'Messages publics',
	'onglet_messages_vide' => 'Messages sans texte',

	// R
	'repondre_message' => 'Réponte à cheul messache',

	// T
	'titre_forum' => 'Forum'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_roa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=roa
// ** ne pas modifier le fichier **

return [

	// F
	'form_pet_message_commentaire' => 'Un message, un commentaire ?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Vous n’avez plus accès à ces forums.',
	'forum_attention_dix_caracteres' => '<b>Attention !</b> votre message doit contenir au moins dix caractères.',
	'forum_attention_trois_caracteres' => '<b>Attention !</b> votre titre doit contenir au moins trois caractères.',
	'forum_attention_trop_caracteres' => '<b>Attention !</b> votre message est trop long (@compte@ caractères) : pour pouvoir être enregistré, il ne doit pas dépasser @max@ caractères.', # MODIF
	'forum_avez_selectionne' => 'Vous avez sélectionné :',
	'forum_cliquer_retour' => 'Cliquez <a href=\'@retour_forum@\'>ici</a> pour continuer.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Ce forum est modéré à priori : votre contribution n’apparaîtra qu’après avoir été validée par un administrateur du site.', # MODIF
	'forum_lien_hyper' => '<b>Lien hypertexte</b> (optionnel)', # MODIF
	'forum_message_definitif' => 'Message définitif : envoyer au site',
	'forum_message_trop_long' => 'Votre message est trop long. La taille maximale est de 20000 caractères.', # MODIF
	'forum_ne_repondez_pas' => 'Ne repondez pas a ce mail mais sur le forum a l’adresse suivante :', # MODIF
	'forum_page_url' => '(Si votre message se réfère à un article publié sur le Web, ou à une page fournissant plus d’informations, vous pouvez indiquer ci-après le titre de la page et son adresse.)',
	'forum_poste_par' => 'Message posté@parauteur@ à la suite de l’article « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Qui êtes-vous ?</b> (optionnel)', # MODIF
	'forum_texte' => 'Texte de votre message :', # MODIF
	'forum_titre' => 'Titre :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Valider ce choix',
	'forum_voir_avant' => 'Voir ce message avant de le poster', # MODIF
	'forum_votre_email' => 'Votre adresse email :', # MODIF
	'forum_votre_nom' => 'Votre nom (ou pseudonyme) :', # MODIF
	'forum_vous_enregistrer' => 'Pour participer à
		ce forum, vous devez vous enregistrer au préalable. Merci
		d’indiquer ci-dessous l’identifiant personnel qui vous a
		été fourni. Si vous n’êtes pas enregistré, vous devez',
	'forum_vous_inscrire' => 'vous inscrire.',

	// I
	'icone_suivi_forums' => 'Suivre/gérer les forums',
	'icone_supprimer_message' => 'Supprimer ce message',
	'icone_valider_message' => 'Valider ce message',
	'info_activer_forum_public' => '<i>Pour activer les forums publics, veuillez choisir leur mode
	de modération par défaut:</i>', # MODIF
	'info_option_email' => 'Lorsqu’un visiteur du site poste un nouveau message dans le forum
		associé à un article, les auteurs de l’article peuvent être
		prévenus de ce message par e-mail. Souhaitez-vous utiliser cette option ?', # MODIF

	// L
	'lien_reponse_site_reference' => 'Réponse au site référencé :', # MODIF

	// O
	'onglet_messages_internes' => 'Messages internes',
	'onglet_messages_publics' => 'Messages publics',
	'onglet_messages_vide' => 'Messages sans texte',

	// R
	'repondre_message' => 'Réponte à cheul messache',

	// T
	'titre_forum' => 'Forum',
];
